Plugin base classes
===================

.. autosummary::
   :nosignatures:

   custodia.plugin.CustodiaPlugin
   custodia.plugin.HTTPAuthenticator
   custodia.plugin.HTTPAuthorizer
   custodia.plugin.CSStore
   custodia.plugin.HTTPConsumer
   custodia.plugin.PluginOption

.. autoclass:: custodia.plugin.CustodiaPlugin
    :members:
    :undoc-members:

.. autoclass:: custodia.plugin.HTTPAuthenticator
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.plugin.HTTPAuthorizer
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.plugin.CSStore
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.plugin.HTTPConsumer
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: custodia.plugin.PluginOption